fn use_pkg_dir(bcx: &BuildContext<'_, '_>, unit: &Unit) -> boolExpand description
Returns whether or not this unit should use a hash in the pkg_dir to make it unique.
fn use_pkg_dir(bcx: &BuildContext<'_, '_>, unit: &Unit) -> boolReturns whether or not this unit should use a hash in the pkg_dir to make it unique.