Function requires_target_installed
Source pub fn requires_target_installed(target: &str) -> bool
Check if the given target has been installed.
Generally disabled should be used to check if cross-compilation is allowed.
And alternate to get the cross target.
You should only use this as a last resort to skip tests,
because it doesn’t report skipped tests as ignored.